@@ -168,7 +168,7 @@ class FluxAgent:
         )
 
     async def register_with_local_agent(self):
-        url = f"http://fluxfluxagent_{self.app_name}:{self.local_fileserver_port}/register"
+        url = f"http://flux{self.primary_agent_name}_{self.app_name}:{self.local_fileserver_port}/register"
         name = f"flux{self.component_name}_{self.app_name}"
 
         if self.superior_address and self.superior_port:
@@ -194,11 +194,13 @@ class FluxAgent:
         self.log.info("Successfully registered with primary agent")
 
     async def update_local_agent(self, data: dict):
-        url = f"http://flux{self.primary_agent_name}_{self.app_name}:{self.local_fileserver_port}/update"
+        url = f"http://flux{self.primary_agent_name}_{self.app_name}:{self.local_fileserver_port}/register"
+        name = f"flux{self.component_name}_{self.app_name}"
 
         if self.superior_address and self.superior_port:
             # this means were a subordinate and not on a flux node, basically testing
-            url = f"http://{self.superior_address}:{self.superior_port}/update"
+            url = f"http://{self.superior_address}:{self.superior_port}/register"
+            name = self.bind_address
 
         try:
             async with ClientSession(timeout=ClientTimeout(3)) as session:
